# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datatransfer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Security_pb2 as Security__pb2
import hdfs_pb2 as hdfs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='datatransfer.proto',
  package='hadoop.hdfs',
  syntax='proto2',
  serialized_pb=_b('\n\x12\x64\x61tatransfer.proto\x12\x0bhadoop.hdfs\x1a\x0eSecurity.proto\x1a\nhdfs.proto\"\xef\x01\n!DataTransferEncryptorMessageProto\x12Z\n\x06status\x18\x01 \x02(\x0e\x32J.hadoop.hdfs.DataTransferEncryptorMessageProto.DataTransferEncryptorStatus\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x0f\n\x07message\x18\x03 \x01(\t\"L\n\x1b\x44\x61taTransferEncryptorStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNKNOWN_KEY\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"k\n\x0f\x42\x61seHeaderProto\x12.\n\x05\x62lock\x18\x01 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12(\n\x05token\x18\x02 \x01(\x0b\x32\x19.hadoop.common.TokenProto\"b\n\x1a\x43lientOperationHeaderProto\x12\x30\n\nbaseHeader\x18\x01 \x02(\x0b\x32\x1c.hadoop.hdfs.BaseHeaderProto\x12\x12\n\nclientName\x18\x02 \x02(\t\"=\n\x14\x43\x61\x63hingStrategyProto\x12\x12\n\ndropBehind\x18\x01 \x01(\x08\x12\x11\n\treadahead\x18\x02 \x01(\x03\"\xc1\x01\n\x10OpReadBlockProto\x12\x37\n\x06header\x18\x01 \x02(\x0b\x32\'.hadoop.hdfs.ClientOperationHeaderProto\x12\x0e\n\x06offset\x18\x02 \x02(\x04\x12\x0b\n\x03len\x18\x03 \x02(\x04\x12\x1b\n\rsendChecksums\x18\x04 \x01(\x08:\x04true\x12:\n\x0f\x63\x61\x63hingStrategy\x18\x05 \x01(\x0b\x32!.hadoop.hdfs.CachingStrategyProto\"W\n\rChecksumProto\x12,\n\x04type\x18\x01 \x02(\x0e\x32\x1e.hadoop.hdfs.ChecksumTypeProto\x12\x18\n\x10\x62ytesPerChecksum\x18\x02 \x02(\r\"\xd2\x05\n\x11OpWriteBlockProto\x12\x37\n\x06header\x18\x01 \x02(\x0b\x32\'.hadoop.hdfs.ClientOperationHeaderProto\x12/\n\x07targets\x18\x02 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\x12.\n\x06source\x18\x03 \x01(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\x12\x44\n\x05stage\x18\x04 \x02(\x0e\x32\x35.hadoop.hdfs.OpWriteBlockProto.BlockConstructionStage\x12\x14\n\x0cpipelineSize\x18\x05 \x02(\r\x12\x14\n\x0cminBytesRcvd\x18\x06 \x02(\x04\x12\x14\n\x0cmaxBytesRcvd\x18\x07 \x02(\x04\x12\x1d\n\x15latestGenerationStamp\x18\x08 \x02(\x04\x12\x35\n\x11requestedChecksum\x18\t \x02(\x0b\x32\x1a.hadoop.hdfs.ChecksumProto\x12:\n\x0f\x63\x61\x63hingStrategy\x18\n \x01(\x0b\x32!.hadoop.hdfs.CachingStrategyProto\"\x88\x02\n\x16\x42lockConstructionStage\x12\x19\n\x15PIPELINE_SETUP_APPEND\x10\x00\x12\"\n\x1ePIPELINE_SETUP_APPEND_RECOVERY\x10\x01\x12\x12\n\x0e\x44\x41TA_STREAMING\x10\x02\x12%\n!PIPELINE_SETUP_STREAMING_RECOVERY\x10\x03\x12\x12\n\x0ePIPELINE_CLOSE\x10\x04\x12\x1b\n\x17PIPELINE_CLOSE_RECOVERY\x10\x05\x12\x19\n\x15PIPELINE_SETUP_CREATE\x10\x06\x12\x10\n\x0cTRANSFER_RBW\x10\x07\x12\x16\n\x12TRANSFER_FINALIZED\x10\x08\"\x80\x01\n\x14OpTransferBlockProto\x12\x37\n\x06header\x18\x01 \x02(\x0b\x32\'.hadoop.hdfs.ClientOperationHeaderProto\x12/\n\x07targets\x18\x02 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\"\x84\x01\n\x13OpReplaceBlockProto\x12,\n\x06header\x18\x01 \x02(\x0b\x32\x1c.hadoop.hdfs.BaseHeaderProto\x12\x0f\n\x07\x64\x65lHint\x18\x02 \x02(\t\x12.\n\x06source\x18\x03 \x02(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\"@\n\x10OpCopyBlockProto\x12,\n\x06header\x18\x01 \x02(\x0b\x32\x1c.hadoop.hdfs.BaseHeaderProto\"D\n\x14OpBlockChecksumProto\x12,\n\x06header\x18\x01 \x02(\x0b\x32\x1c.hadoop.hdfs.BaseHeaderProto\"d\n OpRequestShortCircuitAccessProto\x12,\n\x06header\x18\x01 \x02(\x0b\x32\x1c.hadoop.hdfs.BaseHeaderProto\x12\x12\n\nmaxVersion\x18\x02 \x02(\r\"\x7f\n\x11PacketHeaderProto\x12\x15\n\roffsetInBlock\x18\x01 \x02(\x10\x12\r\n\x05seqno\x18\x02 \x02(\x10\x12\x19\n\x11lastPacketInBlock\x18\x03 \x02(\x08\x12\x0f\n\x07\x64\x61taLen\x18\x04 \x02(\x0f\x12\x18\n\tsyncBlock\x18\x05 \x01(\x08:\x05\x66\x61lse\"i\n\x10PipelineAckProto\x12\r\n\x05seqno\x18\x01 \x02(\x12\x12#\n\x06status\x18\x02 \x03(\x0e\x32\x13.hadoop.hdfs.Status\x12!\n\x16\x64ownstreamAckTimeNanos\x18\x03 \x01(\x04:\x01\x30\"\\\n\x17ReadOpChecksumInfoProto\x12,\n\x08\x63hecksum\x18\x01 \x02(\x0b\x32\x1a.hadoop.hdfs.ChecksumProto\x12\x13\n\x0b\x63hunkOffset\x18\x02 \x02(\x04\"\x8c\x02\n\x14\x42lockOpResponseProto\x12#\n\x06status\x18\x01 \x02(\x0e\x32\x13.hadoop.hdfs.Status\x12\x14\n\x0c\x66irstBadLink\x18\x02 \x01(\t\x12\x43\n\x10\x63hecksumResponse\x18\x03 \x01(\x0b\x32).hadoop.hdfs.OpBlockChecksumResponseProto\x12@\n\x12readOpChecksumInfo\x18\x04 \x01(\x0b\x32$.hadoop.hdfs.ReadOpChecksumInfoProto\x12\x0f\n\x07message\x18\x05 \x01(\t\x12!\n\x19shortCircuitAccessVersion\x18\x06 \x01(\r\"<\n\x15\x43lientReadStatusProto\x12#\n\x06status\x18\x01 \x02(\x0e\x32\x13.hadoop.hdfs.Status\"9\n\x12\x44NTransferAckProto\x12#\n\x06status\x18\x01 \x02(\x0e\x32\x13.hadoop.hdfs.Status\"\x86\x01\n\x1cOpBlockChecksumResponseProto\x12\x13\n\x0b\x62ytesPerCrc\x18\x01 \x02(\r\x12\x13\n\x0b\x63rcPerBlock\x18\x02 \x02(\x04\x12\x0b\n\x03md5\x18\x03 \x02(\x0c\x12/\n\x07\x63rcType\x18\x04 \x01(\x0e\x32\x1e.hadoop.hdfs.ChecksumTypeProto*\x99\x01\n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x12\n\x0e\x45RROR_CHECKSUM\x10\x02\x12\x11\n\rERROR_INVALID\x10\x03\x12\x10\n\x0c\x45RROR_EXISTS\x10\x04\x12\x16\n\x12\x45RROR_ACCESS_TOKEN\x10\x05\x12\x0f\n\x0b\x43HECKSUM_OK\x10\x06\x12\x15\n\x11\x45RROR_UNSUPPORTED\x10\x07\x42>\n%org.apache.hadoop.hdfs.protocol.protoB\x12\x44\x61taTransferProtos\xa0\x01\x01')
  ,
  dependencies=[Security__pb2.DESCRIPTOR,hdfs__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='hadoop.hdfs.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CHECKSUM', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_EXISTS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCESS_TOKEN', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKSUM_OK', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSUPPORTED', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2951,
  serialized_end=3104,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
SUCCESS = 0
ERROR = 1
ERROR_CHECKSUM = 2
ERROR_INVALID = 3
ERROR_EXISTS = 4
ERROR_ACCESS_TOKEN = 5
CHECKSUM_OK = 6
ERROR_UNSUPPORTED = 7


_DATATRANSFERENCRYPTORMESSAGEPROTO_DATATRANSFERENCRYPTORSTATUS = _descriptor.EnumDescriptor(
  name='DataTransferEncryptorStatus',
  full_name='hadoop.hdfs.DataTransferEncryptorMessageProto.DataTransferEncryptorStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN_KEY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=227,
  serialized_end=303,
)
_sym_db.RegisterEnumDescriptor(_DATATRANSFERENCRYPTORMESSAGEPROTO_DATATRANSFERENCRYPTORSTATUS)

_OPWRITEBLOCKPROTO_BLOCKCONSTRUCTIONSTAGE = _descriptor.EnumDescriptor(
  name='BlockConstructionStage',
  full_name='hadoop.hdfs.OpWriteBlockProto.BlockConstructionStage',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_SETUP_APPEND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_SETUP_APPEND_RECOVERY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_STREAMING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_SETUP_STREAMING_RECOVERY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_CLOSE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_CLOSE_RECOVERY', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_SETUP_CREATE', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSFER_RBW', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSFER_FINALIZED', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1321,
  serialized_end=1585,
)
_sym_db.RegisterEnumDescriptor(_OPWRITEBLOCKPROTO_BLOCKCONSTRUCTIONSTAGE)


_DATATRANSFERENCRYPTORMESSAGEPROTO = _descriptor.Descriptor(
  name='DataTransferEncryptorMessageProto',
  full_name='hadoop.hdfs.DataTransferEncryptorMessageProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='hadoop.hdfs.DataTransferEncryptorMessageProto.status', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='hadoop.hdfs.DataTransferEncryptorMessageProto.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='hadoop.hdfs.DataTransferEncryptorMessageProto.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATATRANSFERENCRYPTORMESSAGEPROTO_DATATRANSFERENCRYPTORSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=303,
)


_BASEHEADERPROTO = _descriptor.Descriptor(
  name='BaseHeaderProto',
  full_name='hadoop.hdfs.BaseHeaderProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.BaseHeaderProto.block', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='hadoop.hdfs.BaseHeaderProto.token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=412,
)


_CLIENTOPERATIONHEADERPROTO = _descriptor.Descriptor(
  name='ClientOperationHeaderProto',
  full_name='hadoop.hdfs.ClientOperationHeaderProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseHeader', full_name='hadoop.hdfs.ClientOperationHeaderProto.baseHeader', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.ClientOperationHeaderProto.clientName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=512,
)


_CACHINGSTRATEGYPROTO = _descriptor.Descriptor(
  name='CachingStrategyProto',
  full_name='hadoop.hdfs.CachingStrategyProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dropBehind', full_name='hadoop.hdfs.CachingStrategyProto.dropBehind', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readahead', full_name='hadoop.hdfs.CachingStrategyProto.readahead', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=575,
)


_OPREADBLOCKPROTO = _descriptor.Descriptor(
  name='OpReadBlockProto',
  full_name='hadoop.hdfs.OpReadBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpReadBlockProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='hadoop.hdfs.OpReadBlockProto.offset', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='len', full_name='hadoop.hdfs.OpReadBlockProto.len', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sendChecksums', full_name='hadoop.hdfs.OpReadBlockProto.sendChecksums', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cachingStrategy', full_name='hadoop.hdfs.OpReadBlockProto.cachingStrategy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=771,
)


_CHECKSUMPROTO = _descriptor.Descriptor(
  name='ChecksumProto',
  full_name='hadoop.hdfs.ChecksumProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='hadoop.hdfs.ChecksumProto.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytesPerChecksum', full_name='hadoop.hdfs.ChecksumProto.bytesPerChecksum', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=860,
)


_OPWRITEBLOCKPROTO = _descriptor.Descriptor(
  name='OpWriteBlockProto',
  full_name='hadoop.hdfs.OpWriteBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpWriteBlockProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targets', full_name='hadoop.hdfs.OpWriteBlockProto.targets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='hadoop.hdfs.OpWriteBlockProto.source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='hadoop.hdfs.OpWriteBlockProto.stage', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pipelineSize', full_name='hadoop.hdfs.OpWriteBlockProto.pipelineSize', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minBytesRcvd', full_name='hadoop.hdfs.OpWriteBlockProto.minBytesRcvd', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxBytesRcvd', full_name='hadoop.hdfs.OpWriteBlockProto.maxBytesRcvd', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latestGenerationStamp', full_name='hadoop.hdfs.OpWriteBlockProto.latestGenerationStamp', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requestedChecksum', full_name='hadoop.hdfs.OpWriteBlockProto.requestedChecksum', index=8,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cachingStrategy', full_name='hadoop.hdfs.OpWriteBlockProto.cachingStrategy', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPWRITEBLOCKPROTO_BLOCKCONSTRUCTIONSTAGE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=1585,
)


_OPTRANSFERBLOCKPROTO = _descriptor.Descriptor(
  name='OpTransferBlockProto',
  full_name='hadoop.hdfs.OpTransferBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpTransferBlockProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targets', full_name='hadoop.hdfs.OpTransferBlockProto.targets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1588,
  serialized_end=1716,
)


_OPREPLACEBLOCKPROTO = _descriptor.Descriptor(
  name='OpReplaceBlockProto',
  full_name='hadoop.hdfs.OpReplaceBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpReplaceBlockProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delHint', full_name='hadoop.hdfs.OpReplaceBlockProto.delHint', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='hadoop.hdfs.OpReplaceBlockProto.source', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1851,
)


_OPCOPYBLOCKPROTO = _descriptor.Descriptor(
  name='OpCopyBlockProto',
  full_name='hadoop.hdfs.OpCopyBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpCopyBlockProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1853,
  serialized_end=1917,
)


_OPBLOCKCHECKSUMPROTO = _descriptor.Descriptor(
  name='OpBlockChecksumProto',
  full_name='hadoop.hdfs.OpBlockChecksumProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpBlockChecksumProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1919,
  serialized_end=1987,
)


_OPREQUESTSHORTCIRCUITACCESSPROTO = _descriptor.Descriptor(
  name='OpRequestShortCircuitAccessProto',
  full_name='hadoop.hdfs.OpRequestShortCircuitAccessProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hadoop.hdfs.OpRequestShortCircuitAccessProto.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxVersion', full_name='hadoop.hdfs.OpRequestShortCircuitAccessProto.maxVersion', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1989,
  serialized_end=2089,
)


_PACKETHEADERPROTO = _descriptor.Descriptor(
  name='PacketHeaderProto',
  full_name='hadoop.hdfs.PacketHeaderProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offsetInBlock', full_name='hadoop.hdfs.PacketHeaderProto.offsetInBlock', index=0,
      number=1, type=16, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seqno', full_name='hadoop.hdfs.PacketHeaderProto.seqno', index=1,
      number=2, type=16, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastPacketInBlock', full_name='hadoop.hdfs.PacketHeaderProto.lastPacketInBlock', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dataLen', full_name='hadoop.hdfs.PacketHeaderProto.dataLen', index=3,
      number=4, type=15, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='syncBlock', full_name='hadoop.hdfs.PacketHeaderProto.syncBlock', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2218,
)


_PIPELINEACKPROTO = _descriptor.Descriptor(
  name='PipelineAckProto',
  full_name='hadoop.hdfs.PipelineAckProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seqno', full_name='hadoop.hdfs.PipelineAckProto.seqno', index=0,
      number=1, type=18, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='hadoop.hdfs.PipelineAckProto.status', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='downstreamAckTimeNanos', full_name='hadoop.hdfs.PipelineAckProto.downstreamAckTimeNanos', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2325,
)


_READOPCHECKSUMINFOPROTO = _descriptor.Descriptor(
  name='ReadOpChecksumInfoProto',
  full_name='hadoop.hdfs.ReadOpChecksumInfoProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='checksum', full_name='hadoop.hdfs.ReadOpChecksumInfoProto.checksum', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chunkOffset', full_name='hadoop.hdfs.ReadOpChecksumInfoProto.chunkOffset', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2327,
  serialized_end=2419,
)


_BLOCKOPRESPONSEPROTO = _descriptor.Descriptor(
  name='BlockOpResponseProto',
  full_name='hadoop.hdfs.BlockOpResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='hadoop.hdfs.BlockOpResponseProto.status', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='firstBadLink', full_name='hadoop.hdfs.BlockOpResponseProto.firstBadLink', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='checksumResponse', full_name='hadoop.hdfs.BlockOpResponseProto.checksumResponse', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readOpChecksumInfo', full_name='hadoop.hdfs.BlockOpResponseProto.readOpChecksumInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='hadoop.hdfs.BlockOpResponseProto.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shortCircuitAccessVersion', full_name='hadoop.hdfs.BlockOpResponseProto.shortCircuitAccessVersion', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2422,
  serialized_end=2690,
)


_CLIENTREADSTATUSPROTO = _descriptor.Descriptor(
  name='ClientReadStatusProto',
  full_name='hadoop.hdfs.ClientReadStatusProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='hadoop.hdfs.ClientReadStatusProto.status', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2752,
)


_DNTRANSFERACKPROTO = _descriptor.Descriptor(
  name='DNTransferAckProto',
  full_name='hadoop.hdfs.DNTransferAckProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='hadoop.hdfs.DNTransferAckProto.status', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2754,
  serialized_end=2811,
)


_OPBLOCKCHECKSUMRESPONSEPROTO = _descriptor.Descriptor(
  name='OpBlockChecksumResponseProto',
  full_name='hadoop.hdfs.OpBlockChecksumResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytesPerCrc', full_name='hadoop.hdfs.OpBlockChecksumResponseProto.bytesPerCrc', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crcPerBlock', full_name='hadoop.hdfs.OpBlockChecksumResponseProto.crcPerBlock', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5', full_name='hadoop.hdfs.OpBlockChecksumResponseProto.md5', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crcType', full_name='hadoop.hdfs.OpBlockChecksumResponseProto.crcType', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2814,
  serialized_end=2948,
)

_DATATRANSFERENCRYPTORMESSAGEPROTO.fields_by_name['status'].enum_type = _DATATRANSFERENCRYPTORMESSAGEPROTO_DATATRANSFERENCRYPTORSTATUS
_DATATRANSFERENCRYPTORMESSAGEPROTO_DATATRANSFERENCRYPTORSTATUS.containing_type = _DATATRANSFERENCRYPTORMESSAGEPROTO
_BASEHEADERPROTO.fields_by_name['block'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_BASEHEADERPROTO.fields_by_name['token'].message_type = Security__pb2._TOKENPROTO
_CLIENTOPERATIONHEADERPROTO.fields_by_name['baseHeader'].message_type = _BASEHEADERPROTO
_OPREADBLOCKPROTO.fields_by_name['header'].message_type = _CLIENTOPERATIONHEADERPROTO
_OPREADBLOCKPROTO.fields_by_name['cachingStrategy'].message_type = _CACHINGSTRATEGYPROTO
_CHECKSUMPROTO.fields_by_name['type'].enum_type = hdfs__pb2._CHECKSUMTYPEPROTO
_OPWRITEBLOCKPROTO.fields_by_name['header'].message_type = _CLIENTOPERATIONHEADERPROTO
_OPWRITEBLOCKPROTO.fields_by_name['targets'].message_type = hdfs__pb2._DATANODEINFOPROTO
_OPWRITEBLOCKPROTO.fields_by_name['source'].message_type = hdfs__pb2._DATANODEINFOPROTO
_OPWRITEBLOCKPROTO.fields_by_name['stage'].enum_type = _OPWRITEBLOCKPROTO_BLOCKCONSTRUCTIONSTAGE
_OPWRITEBLOCKPROTO.fields_by_name['requestedChecksum'].message_type = _CHECKSUMPROTO
_OPWRITEBLOCKPROTO.fields_by_name['cachingStrategy'].message_type = _CACHINGSTRATEGYPROTO
_OPWRITEBLOCKPROTO_BLOCKCONSTRUCTIONSTAGE.containing_type = _OPWRITEBLOCKPROTO
_OPTRANSFERBLOCKPROTO.fields_by_name['header'].message_type = _CLIENTOPERATIONHEADERPROTO
_OPTRANSFERBLOCKPROTO.fields_by_name['targets'].message_type = hdfs__pb2._DATANODEINFOPROTO
_OPREPLACEBLOCKPROTO.fields_by_name['header'].message_type = _BASEHEADERPROTO
_OPREPLACEBLOCKPROTO.fields_by_name['source'].message_type = hdfs__pb2._DATANODEINFOPROTO
_OPCOPYBLOCKPROTO.fields_by_name['header'].message_type = _BASEHEADERPROTO
_OPBLOCKCHECKSUMPROTO.fields_by_name['header'].message_type = _BASEHEADERPROTO
_OPREQUESTSHORTCIRCUITACCESSPROTO.fields_by_name['header'].message_type = _BASEHEADERPROTO
_PIPELINEACKPROTO.fields_by_name['status'].enum_type = _STATUS
_READOPCHECKSUMINFOPROTO.fields_by_name['checksum'].message_type = _CHECKSUMPROTO
_BLOCKOPRESPONSEPROTO.fields_by_name['status'].enum_type = _STATUS
_BLOCKOPRESPONSEPROTO.fields_by_name['checksumResponse'].message_type = _OPBLOCKCHECKSUMRESPONSEPROTO
_BLOCKOPRESPONSEPROTO.fields_by_name['readOpChecksumInfo'].message_type = _READOPCHECKSUMINFOPROTO
_CLIENTREADSTATUSPROTO.fields_by_name['status'].enum_type = _STATUS
_DNTRANSFERACKPROTO.fields_by_name['status'].enum_type = _STATUS
_OPBLOCKCHECKSUMRESPONSEPROTO.fields_by_name['crcType'].enum_type = hdfs__pb2._CHECKSUMTYPEPROTO
DESCRIPTOR.message_types_by_name['DataTransferEncryptorMessageProto'] = _DATATRANSFERENCRYPTORMESSAGEPROTO
DESCRIPTOR.message_types_by_name['BaseHeaderProto'] = _BASEHEADERPROTO
DESCRIPTOR.message_types_by_name['ClientOperationHeaderProto'] = _CLIENTOPERATIONHEADERPROTO
DESCRIPTOR.message_types_by_name['CachingStrategyProto'] = _CACHINGSTRATEGYPROTO
DESCRIPTOR.message_types_by_name['OpReadBlockProto'] = _OPREADBLOCKPROTO
DESCRIPTOR.message_types_by_name['ChecksumProto'] = _CHECKSUMPROTO
DESCRIPTOR.message_types_by_name['OpWriteBlockProto'] = _OPWRITEBLOCKPROTO
DESCRIPTOR.message_types_by_name['OpTransferBlockProto'] = _OPTRANSFERBLOCKPROTO
DESCRIPTOR.message_types_by_name['OpReplaceBlockProto'] = _OPREPLACEBLOCKPROTO
DESCRIPTOR.message_types_by_name['OpCopyBlockProto'] = _OPCOPYBLOCKPROTO
DESCRIPTOR.message_types_by_name['OpBlockChecksumProto'] = _OPBLOCKCHECKSUMPROTO
DESCRIPTOR.message_types_by_name['OpRequestShortCircuitAccessProto'] = _OPREQUESTSHORTCIRCUITACCESSPROTO
DESCRIPTOR.message_types_by_name['PacketHeaderProto'] = _PACKETHEADERPROTO
DESCRIPTOR.message_types_by_name['PipelineAckProto'] = _PIPELINEACKPROTO
DESCRIPTOR.message_types_by_name['ReadOpChecksumInfoProto'] = _READOPCHECKSUMINFOPROTO
DESCRIPTOR.message_types_by_name['BlockOpResponseProto'] = _BLOCKOPRESPONSEPROTO
DESCRIPTOR.message_types_by_name['ClientReadStatusProto'] = _CLIENTREADSTATUSPROTO
DESCRIPTOR.message_types_by_name['DNTransferAckProto'] = _DNTRANSFERACKPROTO
DESCRIPTOR.message_types_by_name['OpBlockChecksumResponseProto'] = _OPBLOCKCHECKSUMRESPONSEPROTO
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS

DataTransferEncryptorMessageProto = _reflection.GeneratedProtocolMessageType('DataTransferEncryptorMessageProto', (_message.Message,), dict(
  DESCRIPTOR = _DATATRANSFERENCRYPTORMESSAGEPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DataTransferEncryptorMessageProto)
  ))
_sym_db.RegisterMessage(DataTransferEncryptorMessageProto)

BaseHeaderProto = _reflection.GeneratedProtocolMessageType('BaseHeaderProto', (_message.Message,), dict(
  DESCRIPTOR = _BASEHEADERPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.BaseHeaderProto)
  ))
_sym_db.RegisterMessage(BaseHeaderProto)

ClientOperationHeaderProto = _reflection.GeneratedProtocolMessageType('ClientOperationHeaderProto', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTOPERATIONHEADERPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ClientOperationHeaderProto)
  ))
_sym_db.RegisterMessage(ClientOperationHeaderProto)

CachingStrategyProto = _reflection.GeneratedProtocolMessageType('CachingStrategyProto', (_message.Message,), dict(
  DESCRIPTOR = _CACHINGSTRATEGYPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CachingStrategyProto)
  ))
_sym_db.RegisterMessage(CachingStrategyProto)

OpReadBlockProto = _reflection.GeneratedProtocolMessageType('OpReadBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _OPREADBLOCKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpReadBlockProto)
  ))
_sym_db.RegisterMessage(OpReadBlockProto)

ChecksumProto = _reflection.GeneratedProtocolMessageType('ChecksumProto', (_message.Message,), dict(
  DESCRIPTOR = _CHECKSUMPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ChecksumProto)
  ))
_sym_db.RegisterMessage(ChecksumProto)

OpWriteBlockProto = _reflection.GeneratedProtocolMessageType('OpWriteBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _OPWRITEBLOCKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpWriteBlockProto)
  ))
_sym_db.RegisterMessage(OpWriteBlockProto)

OpTransferBlockProto = _reflection.GeneratedProtocolMessageType('OpTransferBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _OPTRANSFERBLOCKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpTransferBlockProto)
  ))
_sym_db.RegisterMessage(OpTransferBlockProto)

OpReplaceBlockProto = _reflection.GeneratedProtocolMessageType('OpReplaceBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _OPREPLACEBLOCKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpReplaceBlockProto)
  ))
_sym_db.RegisterMessage(OpReplaceBlockProto)

OpCopyBlockProto = _reflection.GeneratedProtocolMessageType('OpCopyBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _OPCOPYBLOCKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpCopyBlockProto)
  ))
_sym_db.RegisterMessage(OpCopyBlockProto)

OpBlockChecksumProto = _reflection.GeneratedProtocolMessageType('OpBlockChecksumProto', (_message.Message,), dict(
  DESCRIPTOR = _OPBLOCKCHECKSUMPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpBlockChecksumProto)
  ))
_sym_db.RegisterMessage(OpBlockChecksumProto)

OpRequestShortCircuitAccessProto = _reflection.GeneratedProtocolMessageType('OpRequestShortCircuitAccessProto', (_message.Message,), dict(
  DESCRIPTOR = _OPREQUESTSHORTCIRCUITACCESSPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpRequestShortCircuitAccessProto)
  ))
_sym_db.RegisterMessage(OpRequestShortCircuitAccessProto)

PacketHeaderProto = _reflection.GeneratedProtocolMessageType('PacketHeaderProto', (_message.Message,), dict(
  DESCRIPTOR = _PACKETHEADERPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.PacketHeaderProto)
  ))
_sym_db.RegisterMessage(PacketHeaderProto)

PipelineAckProto = _reflection.GeneratedProtocolMessageType('PipelineAckProto', (_message.Message,), dict(
  DESCRIPTOR = _PIPELINEACKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.PipelineAckProto)
  ))
_sym_db.RegisterMessage(PipelineAckProto)

ReadOpChecksumInfoProto = _reflection.GeneratedProtocolMessageType('ReadOpChecksumInfoProto', (_message.Message,), dict(
  DESCRIPTOR = _READOPCHECKSUMINFOPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ReadOpChecksumInfoProto)
  ))
_sym_db.RegisterMessage(ReadOpChecksumInfoProto)

BlockOpResponseProto = _reflection.GeneratedProtocolMessageType('BlockOpResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKOPRESPONSEPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.BlockOpResponseProto)
  ))
_sym_db.RegisterMessage(BlockOpResponseProto)

ClientReadStatusProto = _reflection.GeneratedProtocolMessageType('ClientReadStatusProto', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTREADSTATUSPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ClientReadStatusProto)
  ))
_sym_db.RegisterMessage(ClientReadStatusProto)

DNTransferAckProto = _reflection.GeneratedProtocolMessageType('DNTransferAckProto', (_message.Message,), dict(
  DESCRIPTOR = _DNTRANSFERACKPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DNTransferAckProto)
  ))
_sym_db.RegisterMessage(DNTransferAckProto)

OpBlockChecksumResponseProto = _reflection.GeneratedProtocolMessageType('OpBlockChecksumResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _OPBLOCKCHECKSUMRESPONSEPROTO,
  __module__ = 'datatransfer_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.OpBlockChecksumResponseProto)
  ))
_sym_db.RegisterMessage(OpBlockChecksumResponseProto)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%org.apache.hadoop.hdfs.protocol.protoB\022DataTransferProtos\240\001\001'))
# @@protoc_insertion_point(module_scope)
